==> flutter_nearby_messages_api-0.0.2.tar.gz: ios/Classes/NearbyMessagesApiMCMs.m <==
//
//  NearbyMessagesApiMCMs.m
//  nearby_messages_api
//
//  Created by Thomas Cross on 3/2/19.
//

#import "NearbyMessagesApiMCMs.h"
#import <Flutter/Flutter.h>
#import "GNSMessages.h"

static NSString * const kBackgroundModeSaveKey = @"NearbyBackgroundEnabled";
static NSString * const kOnFound = @"onFound";
static NSString * const kOnLost = @"onLost";

@interface NearbyMessagesApiMCMs ()
@property(nonatomic) GNSPermission *nearbyPermission;
@property(nonatomic) FlutterMethodChannel *channel;
@end

@implementation NearbyMessagesApiMCMs

// Private
GNSMessageManager *messageMgr;
GNSStrategy *strategy;
id<GNSPublication> publication;
id<GNSSubscription> subscription;


- (instancetype)init {
    return [self initWithChannel:nil];
}

- (instancetype)initWithChannel:(FlutterMethodChannel *)channel {
    self = [super init];
    if (self) {
        self.channel = channel;
    }
    return self;
}

- (void)setAPIKey:(NSString *)apikey {
    messageMgr = [[GNSMessageManager alloc]
                   initWithAPIKey:apikey
                   paramsBlock:^(GNSMessageManagerParams *params) {
        params.microphonePermissionErrorHandler = ^(BOOL hasError) {
            // Update the UI for microphone permission
        };
        params.bluetoothPowerErrorHandler = ^(BOOL hasError) {
            // Update the UI for Bluetooth power
        };
        params.bluetoothPermissionErrorHandler = ^(BOOL hasError) {
            // Update the UI for Bluetooth permission
        };
    }];
    
    [self setStrategy];
}

// Private
- (void)setStrategy {
    strategy = [GNSStrategy strategyWithParamsBlock:^(GNSStrategyParams *params) {
        params.allowInBackground = NO;
        params.discoveryMediums = kGNSDiscoveryMediumsDefault;
        params.discoveryMode = kGNSDiscoveryModeDefault;
    }];
}

- (void)setGranted {
    [GNSPermission setGranted:YES];
}

/// Starts sharing with a randomized name and scanning for others.
- (void)backgroundSubscribe {
    [self unPublish];
    [self backgroundUnsubscribe];
    
    // Subscribe to messages from nearby devices and display them in the message view.
    NSString *(^stringFromData)(NSData *) = ^(NSData *content) {
        return [[NSString alloc] initWithData:content encoding:NSUTF8StringEncoding];
    };
    subscription = [messageMgr
                     subscriptionWithMessageFoundHandler:^(GNSMessage *message) {
        NSString *messageString = stringFromData(message.content);
        
        [self.channel invokeMethod:kOnFound arguments:messageString];
    }
                     messageLostHandler:^(GNSMessage *message) {
        NSString *messageString = stringFromData(message.content);
        
        [self.channel invokeMethod:kOnLost arguments:messageString];
    } paramsBlock:^(GNSSubscriptionParams *params) {
        params.strategy = strategy;
    }];
    
    [[NSUserDefaults standardUserDefaults] setBool:YES forKey:kBackgroundModeSaveKey];
}

- (void)publish:(NSString *) message {
    [self unPublish];
    [self backgroundUnsubscribe];
    
    // Publish the name to nearby devices.
    GNSMessage *pubMessage = [GNSMessage messageWithContent:[message dataUsingEncoding:NSUTF8StringEncoding]];
    
    publication = [messageMgr publicationWithMessage:pubMessage paramsBlock:^(GNSPublicationParams *params) {
        params.strategy = strategy;
    }];
}

- (void)unPublish {
    publication = nil;
}

- (void)backgroundUnsubscribe {
    subscription = nil;
    [[NSUserDefaults standardUserDefaults] setBool:NO forKey:kBackgroundModeSaveKey];
}

- (void)enableDebugMode {
    [GNSMessageManager setDebugLoggingEnabled:YES];
}

- (void)disableDebugMode {
    [GNSMessageManager setDebugLoggingEnabled:NO];
}

@end

==> flutter_nearby_messages_api-0.0.3.tar.gz: ios/Classes/NearbyMessagesApiMCMs.m <==
//
//  NearbyMessagesApiMCMs.m
//  nearby_messages_api
//
//  Created by Thomas Cross on 3/2/19.
//

#import "NearbyMessagesApiMCMs.h"
#import <Flutter/Flutter.h>
#import "GNSMessages.h"

static NSString * const kOnFound = @"onFound";
static NSString * const kOnLost = @"onLost";
static NSString * const kStatusHandler = @"statusHandler";

@interface NearbyMessagesApiMCMs ()
@property(nonatomic) GNSPermission *nearbyPermission;
@property(nonatomic) FlutterMethodChannel *channel;
@end

@implementation NearbyMessagesApiMCMs

// Private
GNSMessageManager *messageMgr;
GNSStrategy *strategy;
id<GNSPublication> publication;
id<GNSSubscription> subscription;

NSString * const GNSOperationStatusCategories[] = {
    [kGNSOperationStatusInactive] = @"0",
    [kGNSOperationStatusStarting] = @"1",
    [kGNSOperationStatusActive] = @"2"
};


- (instancetype)init {
    return [self initWithChannel:nil];
}

- (instancetype)initWithChannel:(FlutterMethodChannel *)channel {
    self = [super init];
    if (self) {
        self.channel = channel;
    }
    return self;
}

- (void)setAPIKey:(NSString *)apikey {
    messageMgr = [[GNSMessageManager alloc]
                   initWithAPIKey:apikey
                   paramsBlock:^(GNSMessageManagerParams *params) {
        params.microphonePermissionErrorHandler = ^(BOOL hasError) {
            // Update the UI for microphone permission
        };
        params.bluetoothPowerErrorHandler = ^(BOOL hasError) {
            // Update the UI for Bluetooth power
        };
        params.bluetoothPermissionErrorHandler = ^(BOOL hasError) {
            // Update the UI for Bluetooth permission
        };
    }];
    
    [self setStrategy];
}

// Private
- (void)setStrategy {
    strategy = [GNSStrategy strategyWithParamsBlock:^(GNSStrategyParams *params) {
        params.allowInBackground = NO;
        params.discoveryMediums = kGNSDiscoveryMediumsDefault;
        params.discoveryMode = kGNSDiscoveryModeDefault;
    }];
}

- (void)setGranted {
    [GNSPermission setGranted:YES];
}

/// Starts sharing with a randomized name and scanning for others.
- (void)backgroundSubscribe {
    [self unPublish];
    [self backgroundUnsubscribe];
    
    // Subscribe to messages from nearby devices and display them in the message view.
    NSString *(^stringFromData)(NSData *) = ^(NSData *content) {
        return [[NSString alloc] initWithData:content encoding:NSUTF8StringEncoding];
    };
    subscription = [messageMgr
                     subscriptionWithMessageFoundHandler:^(GNSMessage *message) {
        NSString *messageString = stringFromData(message.content);
        
        [self.channel invokeMethod:kOnFound arguments:messageString];
    }
                     messageLostHandler:^(GNSMessage *message) {
        NSString *messageString = stringFromData(message.content);
        
        [self.channel invokeMethod:kOnLost arguments:messageString];
    } paramsBlock:^(GNSSubscriptionParams *params) {
        params.strategy = strategy;
        
        params.statusHandler = ^(GNSOperationStatus status) {
            NSString *statusString = [self getGNSOperationStatusString:status];
            [self.channel invokeMethod:kStatusHandler arguments:statusString];
        };
    }];
}

- (void)publish:(NSString *) message {
    [self unPublish];
    [self backgroundUnsubscribe];
    
    // Publish the name to nearby devices.
    GNSMessage *pubMessage = [GNSMessage messageWithContent:[message dataUsingEncoding:NSUTF8StringEncoding]];
    
    publication = [messageMgr publicationWithMessage:pubMessage paramsBlock:^(GNSPublicationParams *params) {
        params.statusHandler = ^(GNSOperationStatus status) {
            NSString *statusString = [self getGNSOperationStatusString:status];
            [self.channel invokeMethod:kStatusHandler arguments:statusString];
        };
        
        params.strategy = strategy;
    }];
}

- (void)unPublish {
    publication = nil;
}

- (void)backgroundUnsubscribe {
    subscription = nil;
}

- (void)enableDebugMode {
    [GNSMessageManager setDebugLoggingEnabled:YES];
}

- (void)disableDebugMode {
    [GNSMessageManager setDebugLoggingEnabled:NO];
}

- (NSString *)getGNSOperationStatusString:(GNSOperationStatus)status {
    return GNSOperationStatusCategories[status];
}

@end
